@@ -34,11 +34,11 @@ class Token:
     """
 
     def __init__(self, token: str, token_type: str, timestamp: float) -> None:
-        """Initializes a Token object. The expiration time is calculated based
-        on the token type, with a default of 1e10 seconds (about 316 days,
-        this should be basically forever for all intents and purposes, if you
-        have a python session running for that long, you have bigger problems
-        than a token expiring).
+        """Initializes a ``Token`` object. The expiration time is calculated
+        based on the token type, with a default of ``1e10`` seconds (about 316
+        days, this should be basically forever for all intents and purposes; if
+        you have a python session running for that long, you have bigger
+        problems than a token expiring).
 
         Args:
             token (str): The value of the token, this is the actual token.
@@ -141,8 +141,8 @@ class Token:
 
 class TokenManager:
     """Class that manages tokens. This class can be used to add tokens, generate
-    tokens from the NSO class, check if tokens are expired, load tokens from a
-    configuration file or environment variables, save tokens to disk, and
+    tokens from the ``NSO`` class, check if tokens are expired, load tokens from
+    a configuration file or environment variables, save tokens to disk, and
     display the time left before tokens expire among other things.
     """
 
@@ -184,31 +184,31 @@ class TokenManager:
         token_type: str | None = None,
         timestamp: float | None = None,
     ) -> None:
-        """Adds a token to the manager. If the token provided is a `string`, the
-        token type must be provided as well. The manager will then create a new
-        Token object and add it to its internal dictionary. If the token
-        provided is a `Token` object, the object will be added to the manager as
-        is.
+        """Adds a token to the manager. If the token provided is a ``string``,
+        the token type must be provided as well. The manager will then create a
+        new Token object and add it to its internal dictionary. If the token
+        provided is a ``Token`` object, the object will be added to the manager
+        as is.
 
-        If the token type is `session_token`, the token will
+        If the token type is ``session_token``, the token will
 
         Args:
             token (str | Token): The token to add to the manager. If a string,
-                the token type must be provided as well. If a `Token` object,
+                the token type must be provided as well. If a ``Token`` object,
                 the token type will be ignored. This field might also be known
                 as the "access token" or "auth token" among other names.
             token_type (str | None): The type of token. If token is an instance
-                of `Token`, this will be ignored. If token is a string, this
+                of ``Token``, this will be ignored. If token is a string, this
                 must be provided. Currently the only supported token types that
                 are recognized by the manager are "session_token", "gtoken", and
                 "bullet_token". Defaults to None, which will cause an error to
-                be raised if `token` is a string.
+                be raised if ``token`` is a string.
             timestamp (float | None): The time the token was created. If not
                 provided, the current time will be used.
 
         Raises:
-            ValueError: If the `token` provided is a string and `token_type` is
-                not provided.
+            ValueError: If the ``token`` provided is a string and ``token_type``
+                is not provided.
         """
         if timestamp is None:
             timestamp = time.time()
@@ -244,22 +244,22 @@ class TokenManager:
     def get(self, token_type: str, full_token: bool = False) -> str | Token:
         """Gets a token from the manager given a token type.
 
-        If `full_token` is True, the full `Token` object will be returned.
+        If ``full_token`` is True, the full ``Token`` object will be returned.
         Otherwise, just the value of the token will be returned. If the token
         type is not found, a ValueError will be raised.
 
         Args:
             token_type (str): The type of the token to get, as defined in the
-                `Token.token_type` field.
-            full_token (bool): Whether to return the full `Token` object or just
-                the value of the token. Defaults to False.
+                ``Token.token_type`` field.
+            full_token (bool): Whether to return the full ``Token`` object or
+                just the value of the token. Defaults to False.
 
         Raises:
             ValueError: If the given token type is not found in the manager.
 
         Returns:
-            str | Token: The token, either as a string or a `Token` object as
-                defined by the `full_token` argument.
+            str | Token: The token, either as a string or a ``Token`` object as
+                defined by the ``full_token`` argument.
         """
         token_obj = self._tokens.get(token_type, None)
         if token_obj is None:
@@ -273,8 +273,8 @@ class TokenManager:
         """Returns the full data stored in the manager as a dictionary. This
         data is not the same as the tokens stored in the manager, but rather
         additional data that can be used in other places. Examples of keys that
-        might be stored in this dictionary are the user's `country`, and
-        `language` as defined by the Nintendo Account.
+        might be stored in this dictionary are the user's ``country``, and
+        ``language`` as defined by the Nintendo Account.
 
         Returns:
             dict[str, Any]: The data stored in the manager as a dictionary.
@@ -284,7 +284,7 @@ class TokenManager:
     def add_session_token(self, token: str) -> None:
         """Adds a session token to the manager. This is a convenience method
         that will also set the session token in the NSO class. This
-        functionality is already present in the `add_token` method, so this
+        functionality is already present in the ``add_token`` method, so this
         method might be removed in the future.
 
         Args:
@@ -330,9 +330,9 @@ class TokenManager:
     def generate_bullet_token(self) -> None:
         """Generates a new bullet token from the internal NSO class and adds it
         to the manager. This is a convenience method that will also generate a
-        gtoken if one has not already been generated, or if the user info has
-        not been set. This function requires a session token to already be set,
-        and will raise a ValueError if it is not. If the bullet token is
+        ``gtoken`` if one has not already been generated, or if the user info
+        has not been set. This function requires a session token to already be
+        set, and will raise a ValueError if it is not. If the bullet token is
         unable to be generated, a SplatNetException will be raised.
 
         Raises:
@@ -358,8 +358,8 @@ class TokenManager:
 
     def generate_all_tokens(self) -> None:
         """Generates all tokens that can be generated from the manager. This
-        is a convenience method that will call the `generate_gtoken` and
-        `generate_bullet_token` methods in order. This function requires a
+        is a convenience method that will call the ``generate_gtoken`` and
+        ``generate_bullet_token`` methods in order. This function requires a
         session token to already be set, and will raise the errors that those
         methods raise if a session token is not set.
         """
@@ -377,7 +377,7 @@ class TokenManager:
 
         Args:
             session_token (str): The session token to use to instantiate the
-                `TokenManager`.
+                ``TokenManager``.
 
         Returns:
             TokenManager: The token manager with the session token added.
@@ -422,7 +422,7 @@ class TokenManager:
         and add the tokens found in the config file to it. Additionally, it
         will flag the origin of the tokens as "config_file" so that they can be
         saved to a config file later. The config file must be in the format of
-        the standard `configparser` library, and must have a "tokens" section.
+        the standard ``configparser`` library, and must have a "tokens" section.
         The "tokens" section must have a "session_token" option, and may have
         "gtoken" and "bullet_token" options. An example config file is shown
         below:
@@ -440,13 +440,13 @@ class TokenManager:
         ... user_agent = USER_AGENT
 
         Tests the tokens before returning the token manager using the
-        `test_tokens` method.
+        ``test_tokens`` method.
 
         Args:
             path (str): The path to the config file.
 
         Raises:
-            ValueError: If the config file does not have a `tokens` section.
+            ValueError: If the config file does not have a ``tokens`` section.
 
         Returns:
             TokenManager: A newly created token manager with the tokens loaded
@@ -488,7 +488,7 @@ class TokenManager:
         data in the token manager.
 
         Tests the tokens before returning the token manager using the
-        `test_tokens` method.
+        ``test_tokens`` method.
 
         Args:
             path (str): The path to the text file.
@@ -532,11 +532,11 @@ class TokenManager:
         - SN3S_BULLET_TOKEN
 
         The session token environment variable is required, and if it is not
-        set, a `ValueError` will be raised. The other environment variables are
+        set, a ValueError will be raised. The other environment variables are
         optional and will be generated if they are not set.
 
         Tests the tokens before returning the token manager using the
-        `test_tokens` method.
+        ``test_tokens`` method.
 
         Raises:
             ValueError: If the session token environment variable is not set.
@@ -566,13 +566,13 @@ class TokenManager:
     def save(self, path: str | None = None) -> None:
         """Saves the tokens to a config file.
 
-        Uses the `configparser` module to save the tokens to a config file.
+        Uses the ``configparser`` module to save the tokens to a config file.
         The config file will be saved to the path specified by the `path`
         argument. If the `path` argument is not specified, the config file
         will be saved to the current working directory with the name
-        `.splatnet3_scraper`. Does not consider the origin of the tokens, as it
-        is assumed that this method will only be called when the user wants to
-        save the tokens to disk.
+        ``.splatnet3_scraper``. Does not consider the origin of the tokens, as
+        it is assumed that this method will only be called when the user wants
+        to save the tokens to disk.
 
         Args:
             path (str): The path to the config file.
@@ -597,7 +597,7 @@ class TokenManager:
 
         This method will check if the token is valid by checking if the token
         is expired. This method will not regenerate the token if it is invalid.
-        As mentioned in the `Token.is_valid` property, this method will not
+        As mentioned in the ``Token.is_valid`` property, this method will not
         check if the token is valid by making a request to the API, but rather
         checks if the token is likely to be expired by comparing the known
         expiration time of the token to the current time. If the token type is
@@ -618,14 +618,14 @@ class TokenManager:
     def test_tokens(self, user_agent: str | None = None) -> None:
         """Tests the tokens.
 
-        Checks using the `token_is_valid` method` to see whether the tokens need
-        to be regenerated. If so, the tokens will be regenerated with the
-        appropriate `generate_*` method. Once the tokens are regenerated, it
+        Checks using the ``token_is_valid`` method to see whether the tokens
+        need to be regenerated. If so, the tokens will be regenerated with the
+        appropriate ``generate_*`` method. Once the tokens are regenerated, it
         will make a request to the API to check if the tokens are valid. If the
-        request fails, the `generate_all_tokens` method will be called. If the
+        request fails, the ``generate_all_tokens`` method will be called. If the
         requests succeeds, nothing will happen. Once this method is called, the
-        `TokenManager` can be assumed to have valid tokens and can be used to
-        make requests to the API.
+        TokenManager can be assumed to have valid tokens and can be used to make
+        requests to the API.
 
         Args:
             user_agent (str): The user agent to use when making the request to
